#
# spec file for package sshuttle
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pythons python3
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           sshuttle
Version:        1.2.0
Release:        1.2
Summary:        VPN over an SSH tunnel
License:        LGPL-2.1-only
Group:          Development/Languages/Python
URL:            https://github.com/sshuttle/sshuttle
Source0:        https://github.com/sshuttle/sshuttle/archive/refs/tags/v%{version}.tar.gz
Source1:        %{name}.service
Source2:        sysconfig.%{name}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
BuildRequires:  python3-pip
BuildRequires:  python3-poetry-core
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-cov
BuildRequires:  python3-wheel
BuildRequires:  sysuser-tools
Requires(post): %fillup_prereq
BuildArch:      noarch
%sysusers_requires

%description
Transparent proxy server that works as a poor man's VPN. Forwards over ssh.
Doesn't require admin. Supports DNS tunneling.
sshuttle is a program that solves the following case:
- You have access to a remote network via ssh.
- You don't necessarily have admin access on the remote network.
- The remote network has no VPN, or only complex VPN
  protocols (IPsec, PPTP, etc).
- You don't want to create an SSH port forward for every
  single host/port on the remote network.
- You can't use openssh's PermitTunnel feature because
  it's disabled by default on openssh servers; plus it does
  TCP-over-TCP, which has terrible performance.

%prep
%autosetup -p0

%build
(
cd docs/;
sed -i '/_scm/d' conf.py
sed -ri 's/(version = )get_version.*/\1 "%{version}"/g' conf.py
%make_build man
)
%pyproject_wheel

%install
%pyproject_install

install -d -m 755 %{buildroot}%{_mandir}/man1
install -m0644 docs/_build/man/%{name}.1 %{buildroot}/%{_mandir}/man1/

%fdupes %{buildroot}/%{python3_sitelib}/%{name}/

# systemd service
install -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
install -d -m 755 %{buildroot}%{_sbindir}
ln -sf service %{buildroot}%{_sbindir}/rc%{name}

# sysconfig file
install -d -m 755 %{buildroot}%{_fillupdir}
install -m 644 %{SOURCE2} %{buildroot}%{_fillupdir}

%check
%pytest

%pre
getent group %{name} > /dev/null || groupadd -r %{name}
getent passwd %{name} > /dev/null || useradd -r -g %{name} -d %{_localstatedir}/lib/%{name} -s /sbin/nologin -c "%{name} user" %{name}
install -d -m 755 -o %{name} -g %{name} %{_localstatedir}/lib/%{name}
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service
%fillup_only %{name}

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%{python3_sitelib}/%{name}*
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_sbindir}/rc%{name}
%{_unitdir}/%{name}.service
%{_fillupdir}/sysconfig.%{name}

%changelog
* Thu Feb 13 2025 Dirk Müller <dmueller@suse.com>
- update to 1.2.0:
  * Add support for Python 3.11 and Python 3.11
  * bad file descriptor error in windows, fix pytest errors
  * drop Python 3.8 support
  * ensure poetry works for Python 3.9
  * fix broken workflow_dispatch CI rule
  * Remove more references to legacy Python versions
  * replace requirements.txt files with poetry
  * update nix flake to fix problems
  * use Python &gt;= 3.10 for docs
* Wed Oct 23 2024 Dirk Müller <dmueller@suse.com>
- update to 1.1.2:
  * Removed a little bit of legacy code
  * logging priority to turn off noise
  * Add support for SSHUTTLE_ARGS environment variable
  * tproxy: Apply DNS rules first
  * Workaround when sudo prints text to standard out
  * Keep terminal in a sane state when sudo use_pty is used.
  * Allow flake8 to determine the version of pyflakes
- drop fix-pytest.patch: obsolete (added pytest-cov instead)
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Thu Sep 21 2023 Dirk Müller <dmueller@suse.com>
- add sysusers-requires
- remove sle12 specific conditionals
* Tue Jul  4 2023 Johannes Segitz <jsegitz@suse.com>
- Remove
  * PrivateDevices=true
  * ProtectHostname=true
  * ProtectClock=true
  * ProtectKernelTunables=true
  * ProtectKernelModules=true
  * ProtectKernelLogs=true
  * RestrictRealtime=true
  settings from service file as they imply NNP, which doesn't work
  with the sudo setup sshuttle uses (bsc#1212949)
* Mon Jun 12 2023 Dirk Müller <dmueller@suse.com>
- switch to pep517 build for better shebangs
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.1:
  * Make --sudoers option work properly, fix regression in v1.1.0
  * Clarify --disable-ipv6 in man page.
  * Improve message when bind fails with a IPv6 address
  * Add tests for host name resolution
  * Allows wildcard host names as subnets
  * Fix typo
  * Remove --sudoers, improve --sudoers-no-modify
  * avoid moving/renaming the hosts file - fix docker container issue
  * fixed some spelling mistakes
  * Fix incorrect permissions for /etc/hosts
  * This test broke in Python3.11
  * all elements are strings
  * Replace setuptools_scm with bump2version
- drop fix-shebang.patch (obsolete)
* Wed May  4 2022 Dirk Müller <dmueller@suse.com>
- depend on setuptools_scm also on older dists
* Mon Apr 25 2022 pgajdos@suse.com
- version update to 1.1.0
  * Support the sudo use_pty option which is now the default in some operating systems. See #712.
  * Support doas as well as sudo. See #708.
  * for more details see
    https://github.com/sshuttle/sshuttle/releases/
- modified patches
  %% fix-shebang.patch (refreshed)
- python-mock is not required for build
* Tue Dec  7 2021 pgajdos@suse.com
- do not require pytest-runner for build, it is not needed
* Fri Nov 26 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * sshuttle.service
* Fri Jun 18 2021 Loic Devulder <ldevulder@suse.com>
- Sshuttle service should be started after firewalld
* Thu Jun 10 2021 Loic Devulder <ldevulder@suse.com>
- Fix fix-shebang.patch to use /bin/bash and /bin/sh, as older
  distributions don't have /usr/bin/bash
* Wed Jun  9 2021 Loic Devulder <ldevulder@suse.com>
- Add support for a systemd service, this is useful if we want to
  start sshuttle VPN at boot time.
* Fri Feb 19 2021 Dirk Müller <dmueller@suse.com>
- only build for main python3 version, this is not a module
* Mon Jan  4 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.0.5:
  + Added
  * IPv6 support in nft method.
  * Intercept DNS requests sent by systemd-resolved.
  * Set default tmark.
  * Fix python2 server compatibility.
  * Python 3.9 support.
  + Fixed
  * Fix #494 sshuttle caught in infinite select() loop.
  * Include sshuttle version in verbose output.
  * Add psutil as dependency in setup.py
  * When subnets and excludes are specified with hostnames, use all IPs.
  * Update/document client's handling of IPv4 and IPv6.
  * Update sdnotify.py documentation.
  * Allow no remote to work.
  * Make prefixes in verbose output more consistent.
  * Make nat and nft rules consistent; improve rule ordering.
  * Make server and client handle resolv.conf differently.
  * Fix handling OSError in FirewallClient#__init__
  * Refactor automatic method selection.
* Wed Oct 28 2020 Michael Ströder <michael@stroeder.com>
- Update to 1.0.4:
  * Allow Mux() flush/fill to work with python < 3.5
  * Fix parse_hostport to always return string for host.
  * Require -r/--remote parameter.
  * Add missing package in OpenWRT documentation.
  * Fix doc about --listen option.
  * README: add Ubuntu.
  * Increase IP4 ttl to 63 hops instead of 42.
  * Fix formatting in installation.rst
* Tue Jul 28 2020 Martin Rey <mrey@suse.com>
- Update to 1.0.3:
  * Fixed:
  - Ask setuptools to require Python 3.5 and above.
  - Add missing import.
  - Fix formatting typos in usage docs
- Add fix-shebang.patch to fix env-script-interpreter rpmlint error
* Tue Jun 23 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.0.2:
  + Added:
  * Python 3.8 support.
  * sshpass support.
  * Auto sudoers file (#269).
  * option for latency control buffer size.
  + Removed:
  * Python 2.6 support.
  * Python 2.7 support.
  + Fixed:
  * Leave use of default port to ssh command.
  * Remove unwanted references to Python 2.7 in docs.
  * Replace usage of deprecated imp.
  * Fix connection with @ sign in username.
  * Remove debug message for getpeername failure.
  * Fix crash triggered by port scans closing socket.
  * Added "Running as a service" to docs.
  * Systemd integration.
  * Trap UnicodeError to handle cases where hostnames returned by DNS are invalid.
  * Formatting error in CHANGES.rst
  * Various errors in documentation.
  * Nftables based method.
  * Make hostwatch locale-independent (#379).
  * Add tproxy udp port mark filter that was missed in #144, fixes #367.
  * Capturing of local DNS servers.
  * Crashing on ECONNABORTED.
  * Size of pf_rule, which grew in OpenBSD 6.4.
  * Use prompt for sudo, not needed for doas.
  * Arch linux installation instructions.
  * tests for existing PR-312 (#337).
  * Hyphen in hostname.
  * Assembler import (#319)
  - add fix-pytest.patch
* Mon Apr  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add the missing build dependency for openSUSE Factory.
* Tue Nov  6 2018 Dirk Mueller <dmueller@suse.com>
- update to 0.78.4:
  * Work around non tabular headers in BSD netstat.
  * Fix UDP and DNS support on Python 2.7 with tproxy method.
  * Fixed tests after adding support for iproute2.
  * Small refactoring of netstat/iproute parsing.
  * Set started_by_sshuttle False after disabling pf.
  * Fix punctuation and explain Type=notify.
  * Move pytest-runner to tests_require.
  * Fix warning: closed channel got=STOP_SENDING.
  * Support sdnotify for better systemd integration.
  * Fix #117 to allow for no subnets via file (-s).
  * Fix argument splitting for multi-word arguments.
  * requirements.rst: Fix mistakes.
  * Fix typo, space not required here.
  * Update installation instructions.
  * Support using run from different directory.
  * Ensure we update sshuttle/version.py in run.
  * Don't print python version in run.
  * Add CWD to PYTHONPATH in run
  * Fix case where there is no --dns.
  * [pf] Avoid port forwarding from loopback address.
  * Use getaddrinfo to obtain a correct sockaddr.
  * Skip empty lines on incoming routes data.
  * Just skip empty lines of routes data instead of stopping processing.
  * [pf] Load pf kernel module when enabling pf.
  * [pf] Test double restore (ipv4, ipv6) disables only once; test kldload.
  * Fixes UDP and DNS proxies binding to the same socket address.
  * Mock socket bind to avoid depending on local IPs being available in test box.
  * Fix no value passed for argument auto_hosts in hw_main call.
  * Fixed incorrect license information in setup.py.
  * Preserve peer and port properly.
  * Make --to-dns and --ns-host work well together.
  * Remove test that fails under OSX.
  * Specify pip requirements for tests.
  * Use flake8 to find Python syntax errors or undefined names.
  * Fix compatibility with the sudoers file.
  * Stop using SO_REUSEADDR on sockets.
  * Declare 'verbosity' as global variable to placate linters.
  * Adds 'cd sshuttle' after 'git' to README and docs.
  * Documentation for loading options from configuration file.
  * Load options from a file.
  * Fix firewall.py.
  * Move sdnotify after setting up firewall rules.
  * Fix tests on Macos.
- Switch to Python 3.x, python 2.x is dead.
- Fix missing setuptools runtime dependency
- remove weird local copy of setuptools, use system provided one
* Thu May 25 2017 jengelh@inai.de
- Ensure neutrality of description.
* Tue May  9 2017 matthias.eliasson@gmail.com
- Change license to correct (LGPL-2.1)
- Remove patch sshuttle-remove_python2.patch file not needed.
* Tue Nov  8 2016 boris@steki.net
- moved upstream from apenwarr/sshuttle to (pip) sshuttle/sshuttle
  ( brianmay is maintaning fork and original updates anyway)
- upgrade to 0.78.1
  + moved to semantic versioning
  + Fix readthedocs versioning.
  + Improvements to BSD and OSX support
  + Don't force IPv6 if IPv6 nameservers supplied. Fixes #74.
  + Call /bin/sh as users shell may not be POSIX compliant. Fixes #77.
  + Use argparse for command line processing. Fixes #75.
  + Remove useless --server option.
  + Support multiple -s (subnet) options. Fixes #86.
  + Make server parts work with old versions of Python. Fixes #81.
  + Move documentation, including man page, to Sphinx.
  + Python 3.5 fixes
- removed patch sshuttle-remove_python2.patch not required
* Wed Apr  1 2015 wagner-thomas@gmx.at
- upgrade to 0.6.1
- added building the man page
- fixed outdated licence string
* Wed May  4 2011 pascal.bleser@opensuse.org
- initial version (0.20110503)
